#ifndef READAHEAD_H
#define READAHEAD_H

#include <state.h>

int preload_readahead (preload_map_t **files, int file_count);

#endif
